summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/batchprocessimages/convertoptionsdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/batchprocessimages/convertoptionsdialog.cpp')
-rw-r--r--kipi-plugins/batchprocessimages/convertoptionsdialog.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/kipi-plugins/batchprocessimages/convertoptionsdialog.cpp b/kipi-plugins/batchprocessimages/convertoptionsdialog.cpp
index 46ece4b..33eae6a 100644
--- a/kipi-plugins/batchprocessimages/convertoptionsdialog.cpp
+++ b/kipi-plugins/batchprocessimages/convertoptionsdialog.cpp
@@ -20,17 +20,17 @@
*
* ============================================================ */
-// Include files for Qt
-
-#include <qvbox.h>
-#include <qlayout.h>
-#include <qwidget.h>
-#include <qwhatsthis.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
+// Include files for TQt
+
+#include <tqvbox.h>
+#include <tqlayout.h>
+#include <tqwidget.h>
+#include <tqwhatsthis.h>
+#include <tqlabel.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
+#include <tqcombobox.h>
+#include <tqcheckbox.h>
// Include files for KDE
@@ -45,18 +45,18 @@
namespace KIPIBatchProcessImagesPlugin
{
-ConvertOptionsDialog::ConvertOptionsDialog(QWidget *parent, int ImageFormatType)
- : KDialogBase( parent, "ConvertOptionsDialog", true,
+ConvertOptionsDialog::ConvertOptionsDialog(TQWidget *tqparent, int ImageFormatType)
+ : KDialogBase( tqparent, "ConvertOptionsDialog", true,
i18n("Image File Format Options"), Ok|Cancel, Ok, false)
{
- QWidget* box = new QWidget( this );
+ TQWidget* box = new TQWidget( this );
setMainWidget(box);
- QVBoxLayout *dvlay = new QVBoxLayout( box, 10, spacingHint() );
- QString whatsThis;
+ TQVBoxLayout *dvlay = new TQVBoxLayout( box, 10, spacingHint() );
+ TQString whatsThis;
if (ImageFormatType == 0 || ImageFormatType == 1) // JPEG || PNG
{
- m_label_imageCompression = new QLabel (i18n("Image compression level:"), box);
+ m_label_imageCompression = new TQLabel (i18n("Image compression level:"), box);
dvlay->addWidget( m_label_imageCompression );
m_JPEGPNGCompression = new KIntNumInput(75, box);
m_JPEGPNGCompression->setRange(1, 100, 1, true );
@@ -67,42 +67,42 @@ ConvertOptionsDialog::ConvertOptionsDialog(QWidget *parent, int ImageFormatType)
"<b>75</b>: low compression (default value)<p>"
"<b>100</b>: no compression");
- QWhatsThis::add( m_JPEGPNGCompression, whatsThis);
+ TQWhatsThis::add( m_JPEGPNGCompression, whatsThis);
m_label_imageCompression->setBuddy( m_JPEGPNGCompression );
dvlay->addWidget( m_JPEGPNGCompression );
if (ImageFormatType == 0) // JPEG
{
- m_compressLossLess = new QCheckBox( i18n("Use lossless compression"), box);
- QWhatsThis::add( m_compressLossLess, i18n("<p>If this option is enabled, "
+ m_compressLossLess = new TQCheckBox( i18n("Use lossless compression"), box);
+ TQWhatsThis::add( m_compressLossLess, i18n("<p>If this option is enabled, "
"all JPEG operations will use a lossless compression."));
dvlay->addWidget( m_compressLossLess );
- connect(m_compressLossLess, SIGNAL( toggled(bool) ), this, SLOT( slotCompressLossLessEnabled(bool) ) );
+ connect(m_compressLossLess, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( slotCompressLossLessEnabled(bool) ) );
}
}
if (ImageFormatType == 2) // TIFF
{
- QLabel *m_label_imageCompression = new QLabel (i18n("Image compression algorithm:"), box);
+ TQLabel *m_label_imageCompression = new TQLabel (i18n("Image compression algorithm:"), box);
dvlay->addWidget( m_label_imageCompression );
- m_TIFFCompressionAlgo = new QComboBox( false, box );
+ m_TIFFCompressionAlgo = new TQComboBox( false, box );
m_TIFFCompressionAlgo->insertItem("LZW");
m_TIFFCompressionAlgo->insertItem("JPEG");
m_TIFFCompressionAlgo->insertItem(i18n("None"));
- QWhatsThis::add( m_TIFFCompressionAlgo, i18n("<p>Select here the compression algorithm.") );
+ TQWhatsThis::add( m_TIFFCompressionAlgo, i18n("<p>Select here the compression algorithm.") );
m_label_imageCompression->setBuddy( m_TIFFCompressionAlgo );
dvlay->addWidget( m_TIFFCompressionAlgo );
}
if (ImageFormatType == 5) // TGA
{
- QLabel *m_label_imageCompression = new QLabel (i18n("Image compression algorithm:"), box);
+ TQLabel *m_label_imageCompression = new TQLabel (i18n("Image compression algorithm:"), box);
dvlay->addWidget( m_label_imageCompression );
- m_TGACompressionAlgo = new QComboBox( false, box );
+ m_TGACompressionAlgo = new TQComboBox( false, box );
m_TGACompressionAlgo->insertItem("RLE");
m_TGACompressionAlgo->insertItem(i18n("None"));
- QWhatsThis::add( m_TGACompressionAlgo, i18n("<p>Select here the compression algorithm.") );
+ TQWhatsThis::add( m_TGACompressionAlgo, i18n("<p>Select here the compression algorithm.") );
m_label_imageCompression->setBuddy( m_TGACompressionAlgo );
dvlay->addWidget( m_TGACompressionAlgo );
}